@@ -180,6 +180,7 @@ class ProjectPluginEnum(Enum):
     ACCOUNTING_EDM = 'accounting_edm'
     ACCOUNTING_EDM_NSO = 'accounting_edm_nso'
     ACCOUNTING_EDM_RT = 'accounting_edm_rt'
+    ACCOUNTING_MCHS = 'accounting_mchs'
     ACCOUNTING_MIS_INTEGRATION_SERVICE = 'accounting_mis_integration_service'
     ACCOUNTING_WEBSERVICES = 'accounting_webservices'
     ACCOUNT_STATEMENT = 'account_statement'
@@ -222,7 +223,6 @@ class ProjectPluginEnum(Enum):
     LOAD_LIMITS = 'load_limits'
     LOAD_PLAN = 'load_plan'
     MAGIC_ANALYTIC = 'magic_analytic'
-    ACCOUNTING_MCHS = 'accounting_mchs'
     NOMER_DOGOVORA = 'nomer_dogovora'
     NOVOSIB_SERVICE_PF_ACT = 'novosib_service_pf_act'
     OPERATIONS_JOURNAL_04_ACCOUNTS_ANALYTICS = 'operations_journal_04_accounts_analytics'
@@ -282,6 +282,7 @@ class ProjectPluginEnum(Enum):
     SALARY_STAFFING_STRENGTH_EXPORT = 'salary.staffing_strength_export'
     SALARY_WORK_SCHEDULE = 'salary.work_schedule'
     SALARY_ZDRAV = 'salary.zdrav'
+    SALARY_ZKR = 'salary.zkr'
     SALARY_SAMARA = 'salary_samara'
     SALARY_WEBSERVICES = 'salary_webservices'
     SLR_BANK_EXCHANGE = 'slr_bank_exchange'
@@ -417,6 +418,7 @@ class ProjectPluginEnum(Enum):
                     cls.ACCOUNTING_EDM,
                     cls.ACCOUNTING_EDM_NSO,
                     cls.ACCOUNTING_EDM_RT,
+                    cls.ACCOUNTING_MCHS,
                     cls.ACCOUNTING_MIS_INTEGRATION_SERVICE,
                     cls.ACCOUNTING_WEBSERVICES,
                     cls.ACCOUNT_STATEMENT,
@@ -459,7 +461,6 @@ class ProjectPluginEnum(Enum):
                     cls.LOAD_LIMITS,
                     cls.LOAD_PLAN,
                     cls.MAGIC_ANALYTIC,
-                    cls.ACCOUNTING_MCHS,
                     cls.NOMER_DOGOVORA,
                     cls.NOVOSIB_SERVICE_PF_ACT,
                     cls.OSS,
@@ -500,6 +501,9 @@ class ProjectPluginEnum(Enum):
             cls.ACCOUNTING_EDM_RT: (
                 cls.ACCOUNTING_EDM,
             ),
+            cls.ACCOUNTING_MCHS: (
+                cls.ACCOUNTING,
+            ),
             cls.ACCOUNTING_MIS_INTEGRATION_SERVICE: (
                 cls.ACCOUNTING,
             ),
@@ -627,9 +631,6 @@ class ProjectPluginEnum(Enum):
             cls.MAGIC_ANALYTIC: (
                 cls.ACCOUNTING,
             ),
-            cls.ACCOUNTING_MCHS: (
-                cls.ACCOUNTING,
-            ),
             cls.NOMER_DOGOVORA: (
                 cls.ACCOUNTING,
             ),
@@ -735,6 +736,7 @@ class ProjectPluginEnum(Enum):
                     cls.SALARY_STAFFING_STRENGTH_EXPORT,
                     cls.SALARY_WORK_SCHEDULE,
                     cls.SALARY_ZDRAV,
+                    cls.SALARY_ZKR,
                     cls.SALARY_SAMARA,
                     cls.SALARY_WEBSERVICES,
                     cls.SLR_BANK_EXCHANGE,
@@ -878,6 +880,9 @@ class ProjectPluginEnum(Enum):
             cls.SALARY_ZDRAV: (
                 cls.SALARY,
             ),
+            cls.SALARY_ZKR: (
+                cls.SALARY,
+            ),
             cls.SALARY_SAMARA: (
                 cls.SALARY,
             ),
